@@ -52,16 +52,16 @@ impl<'lock> Outdated<'lock> {
             text_range,
         };
         sonar::Issue {
-            engine_id: OUTDATED_ENGINE.to_string(),
+            engine_id: OUTDATED_ENGINE.to_owned(),
             rule_id: format!("{}::{}", OUTDATED_ENGINE, metadata.name),
             severity: sonar::Severity::Minor,
-            r#type: sonar::IssueType::CodeSmell,
+            r#type: sonar::Type::CodeSmell,
             primary_location,
             secondary_locations: Vec::new(),
         }
     }
 
-    pub(crate) fn to_issues(&self, crate_metadata: CrateMetadata) -> sonar::Report {
+    pub(crate) fn to_issues(&self, crate_metadata: CrateMetadata) -> sonar::Issues {
         crate_metadata
             .dependencies
             .into_iter()
@@ -70,10 +70,10 @@ impl<'lock> Outdated<'lock> {
     }
 }
 
-impl std::convert::TryInto<sonar::Report> for Outdated<'_> {
+impl std::convert::TryInto<sonar::Issues> for Outdated<'_> {
     type Error = eyre::Error;
 
-    fn try_into(self) -> Result<sonar::Report> {
+    fn try_into(self) -> Result<sonar::Issues> {
         let file = File::open(&self.json).with_context(|| {
             format!(
                 "failed to open 'cargo-outdated' report from '{:?}' file",
